<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="nl_BE">
<context>
    <name>QvkAudioController</name>
    <message>
        <source>Select one or more devices</source>
        <translation>Selecteer één of meer apparaten</translation>
    </message>
</context>
<context>
    <name>QvkCameraController</name>
    <message>
        <source>Camera</source>
        <translation>Camera</translation>
    </message>
</context>
<context>
    <name>QvkCameraSettingsDialog</name>
    <message>
        <source>Camera settings</source>
        <translation>Camera instellingen</translation>
    </message>
</context>
<context>
    <name>QvkCameraSingle</name>
    <message>
        <source>Remove window frame</source>
        <translation>Vensterrand verwijderen</translation>
    </message>
    <message>
        <source>Flip vertical</source>
        <translation>Verticaal spiegelen</translation>
    </message>
    <message>
        <source>Flip horizontal</source>
        <translation>Horizontaal spiegelen</translation>
    </message>
    <message>
        <source>Invert</source>
        <translation>Omkeren</translation>
    </message>
    <message>
        <source>Gray</source>
        <translation>Grijs</translation>
    </message>
    <message>
        <source>Black-and-white</source>
        <translation>Zwart-wit</translation>
    </message>
    <message>
        <source>Switch to Window</source>
        <translation>Vensterweergave</translation>
    </message>
    <message>
        <source>Switch to Fullscreen</source>
        <translation>Schermvullende weergave</translation>
    </message>
</context>
<context>
    <name>QvkCameraWindow</name>
    <message>
        <source>Switch to Window</source>
        <translation>Vensterweergave</translation>
    </message>
    <message>
        <source>Switch to Fullscreen</source>
        <translation>Schermvullende weergave</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>Camera</translation>
    </message>
</context>
<context>
    <name>QvkCiscoFinishDialog</name>
    <message>
        <source>The setup was successful.</source>
        <translation>Het instellen is voltooid.</translation>
    </message>
    <message>
        <source>Close this window and start vokoscreenNG again.</source>
        <translation>Sluit dit venster en herstart vokoscreenNG.</translation>
    </message>
    <message>
        <source>Have fun with vokoscreenNG</source>
        <translation>Veel plezier met vokoscreenNG</translation>
    </message>
</context>
<context>
    <name>QvkDirDialog</name>
    <message>
        <source>Dialog</source>
        <translation>Dialoogvenster</translation>
    </message>
</context>
<context>
    <name>QvkDirectSoundController</name>
    <message>
        <source>Select one or more devices</source>
        <translation>Selecteer één of meer apparaten</translation>
    </message>
</context>
<context>
    <name>QvkHelp</name>
    <message>
        <source>Help</source>
        <translation>Hulp</translation>
    </message>
</context>
<context>
    <name>QvkImageFromTabs</name>
    <message>
        <source>No filemanager found.</source>
        <translation>Er is geen bestandsbeheerder aangetroffen.</translation>
    </message>
    <message>
        <source>Please install a filemanager.</source>
        <translation>Installeer een bestandsbeheerder.</translation>
    </message>
</context>
<context>
    <name>QvkLimitDiskFreeSpace</name>
    <message>
        <source>Warning</source>
        <translation>Waarschuwing</translation>
    </message>
    <message>
        <source>The recording is not started, not enough free disk space.</source>
        <translation>De opname kan niet worden gestart omdat er onvoldoende vrije schijfruimte is.</translation>
    </message>
    <message>
        <source>The free disk space limit is reached.</source>
        <translation>De vrije schijfruimte limiet is bereikt.</translation>
    </message>
    <message>
        <source>Limit of free disk space</source>
        <translation>Vrije schijfruimte limiet</translation>
    </message>
    <message>
        <source>Megabyte</source>
        <translation>Megabyte</translation>
    </message>
    <message>
        <source>The recording was stopped, not enough free disk space.</source>
        <translation>De opname is gestopt omdat er onvoldoende vrije schijfruimte is.</translation>
    </message>
</context>
<context>
    <name>QvkMainWindow</name>
    <message>
        <source>No filemanager found.</source>
        <extracomment>Display a MessageBox, if not found a filemanager.</extracomment>
        <translation>Er is geen bestandsbeheerder aangetroffen.</translation>
    </message>
    <message>
        <source>Please install a filemanager.</source>
        <translation>Installeer een bestandsbeheerder.</translation>
    </message>
    <message>
        <source>Sourcecode</source>
        <translation>Broncode</translation>
    </message>
    <message>
        <source>Homepage</source>
        <translation>Website</translation>
    </message>
    <message>
        <source>Translations</source>
        <translation>Vertalingen</translation>
    </message>
    <message>
        <source>Donate</source>
        <translation>Doneren</translation>
    </message>
</context>
<context>
    <name>QvkMainWindow_wl</name>
    <message>
        <source>Sourcecode</source>
        <translation>Broncode</translation>
    </message>
    <message>
        <source>Homepage</source>
        <translation>Website</translation>
    </message>
    <message>
        <source>Translations</source>
        <translation>Vertalingen</translation>
    </message>
    <message>
        <source>Donate</source>
        <translation>Doneren</translation>
    </message>
</context>
<context>
    <name>QvkPulseAudioWatcher</name>
    <message>
        <source>Select one or more devices</source>
        <translation>Selecteer één of meer apparaten</translation>
    </message>
</context>
<context>
    <name>QvkRegionChoise</name>
    <message>
        <source>Area</source>
        <translation>Gebied</translation>
    </message>
</context>
<context>
    <name>QvkRegionChoise_wl</name>
    <message>
        <source>Area</source>
        <translation>Gebied</translation>
    </message>
</context>
<context>
    <name>QvkSnapshot</name>
    <message>
        <source>No filemanager found.</source>
        <translation>Er is geen bestandsbeheerder aangetroffen.</translation>
    </message>
    <message>
        <source>Please install a filemanager.</source>
        <translation>Installeer een bestandsbeheerder.</translation>
    </message>
</context>
<context>
    <name>QvkSystray</name>
    <message>
        <source>Start</source>
        <translation>Start</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Stop</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pauzeren</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Hervatten</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Afsluiten</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>Camera</translation>
    </message>
    <message>
        <source>Magnification</source>
        <translation>Vergroting</translation>
    </message>
</context>
<context>
    <name>QvkSystrayAlternative</name>
    <message>
        <source>Start</source>
        <translation>Start</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Stop</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pauze</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Hervatten</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Afsluiten</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>Camera</translation>
    </message>
    <message>
        <source>Magnification</source>
        <translation>Vergroting</translation>
    </message>
</context>
<context>
    <name>QvkWASAPIController</name>
    <message>
        <source>Select one or more devices</source>
        <translation>Selecteer één of meer apparaten</translation>
    </message>
</context>
<context>
    <name>cameraSettingsDialog</name>
    <message>
        <source>Dialog</source>
        <translation>Dialoogvenster</translation>
    </message>
    <message>
        <source>Flip horizontal</source>
        <translation>Horizontaal spiegelen</translation>
    </message>
    <message>
        <source>Flip vertical</source>
        <translation>Verticaal spiegelen</translation>
    </message>
    <message>
        <source>Invert</source>
        <translation>Omkeren</translation>
    </message>
    <message>
        <source>Gray</source>
        <translation>Grijs</translation>
    </message>
    <message>
        <source>Black-and-white</source>
        <translation>Zwart-wit</translation>
    </message>
    <message>
        <source>Remove window frame</source>
        <translation>Vensterrand verwijderen</translation>
    </message>
    <message>
        <source>Camera settings</source>
        <translation>Camera instellingen</translation>
    </message>
</context>
<context>
    <name>formMainWindow</name>
    <message>
        <source>Area</source>
        <translation>Gebied</translation>
    </message>
    <message>
        <source>Reset</source>
        <translation>Standaardwaarden</translation>
    </message>
    <message>
        <source>Magnification</source>
        <translation>Vergroting</translation>
    </message>
    <message>
        <source>Countdown</source>
        <translation>Aftellen</translation>
    </message>
    <message>
        <source>Video size:</source>
        <translation>Videoformaat:</translation>
    </message>
    <message>
        <source>Free disk space:</source>
        <translation>Vrije schijfruimte:</translation>
    </message>
    <message>
        <source>Information</source>
        <translation>Informatie</translation>
    </message>
    <message>
        <source>Record Time:</source>
        <translation>Opnametijd:</translation>
    </message>
    <message>
        <source>Audio</source>
        <translation>Audio</translation>
    </message>
    <message>
        <source>Frames</source>
        <translation>Frames</translation>
    </message>
    <message>
        <source>Videocodec</source>
        <translation>Videocodec</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>Formaat</translation>
    </message>
    <message>
        <source>Audiocodec</source>
        <translation>Audiocodec</translation>
    </message>
    <message>
        <source>Do not record mouse cursor</source>
        <translation>Muis cursor niet opnemen</translation>
    </message>
    <message>
        <source>Hour</source>
        <translation>Uur</translation>
    </message>
    <message>
        <source>Minute</source>
        <translation>Minuut</translation>
    </message>
    <message>
        <source>Start the timer</source>
        <translation>Timer starten</translation>
    </message>
    <message>
        <source>Stop recording after</source>
        <translation>Opname stoppen na</translation>
    </message>
    <message>
        <source>Hours</source>
        <translation>Uur</translation>
    </message>
    <message>
        <source>Minutes</source>
        <translation>Minuten</translation>
    </message>
    <message>
        <source>Seconds</source>
        <translation>Seconden</translation>
    </message>
    <message>
        <source>Videopath</source>
        <translation>Video map</translation>
    </message>
    <message>
        <source>Limit of free disk space</source>
        <translation>Vrije schijfruimte limiet</translation>
    </message>
    <message>
        <source>Show in systray</source>
        <translation>Tonen in systeemvak</translation>
    </message>
    <message>
        <source>Second wait before recording</source>
        <translation>Aantal seconden voordat opname start</translation>
    </message>
    <message>
        <source>Look for updates</source>
        <translation>Controleren op updates</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Hulp</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>Video</translation>
    </message>
    <message>
        <source>Available</source>
        <translation>Beschikbaar</translation>
    </message>
    <message>
        <source>Not available</source>
        <translation>Niet beschikbaar</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>Start</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Stop</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pauzeren</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Hervatten</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>Afspelen</translation>
    </message>
    <message>
        <source>Folder</source>
        <translation>Map</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>Camera</translation>
    </message>
    <message>
        <source>Invert</source>
        <translation>Omkeren</translation>
    </message>
    <message>
        <source>Gray</source>
        <translation>Grijs</translation>
    </message>
    <message>
        <source>CTRL+SHIFT+F10</source>
        <translation>CTRL+SHIFT+F10</translation>
    </message>
    <message>
        <source>CTRL+SHIFT+F11</source>
        <translation>CTRL+SHIFT+F11</translation>
    </message>
    <message>
        <source>CTRL+SHIFT+F12</source>
        <translation>CTRL+SHIFT+F12</translation>
    </message>
    <message>
        <source>Play last record</source>
        <translation>Laatste opname afspelen</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>Map openen</translation>
    </message>
    <message>
        <source>CTRL+SHIFT+F8</source>
        <translation>CTRL+SHIFT+F8</translation>
    </message>
    <message>
        <source>Minimized when recording starts</source>
        <translation>Minimaliseren zodra opname start</translation>
    </message>
    <message>
        <source>Starts minimized</source>
        <translation>Geminimaliseerd starten</translation>
    </message>
    <message>
        <source>Flip horizontal</source>
        <translation>Horizontaal spiegelen</translation>
    </message>
    <message>
        <source>Flip vertical</source>
        <translation>Verticaal spiegelen</translation>
    </message>
    <message>
        <source>Black-and-white</source>
        <translation>Zwart-wit</translation>
    </message>
    <message>
        <source>Remove window frame</source>
        <translation>Vensterrand verwijderen</translation>
    </message>
    <message>
        <source>Reset all settings at the next start</source>
        <translation>Alle instellingen herstellen bij opnieuw opstarten</translation>
    </message>
    <message>
        <source>Copyright and license from pictures</source>
        <translation>Copyright en licentie uit afbeeldingen</translation>
    </message>
    <message>
        <source>Megabyte</source>
        <translation>Megabyte</translation>
    </message>
    <message>
        <source>Screencast</source>
        <translation>Screencast</translation>
    </message>
    <message>
        <source>Player</source>
        <translation>Speler</translation>
    </message>
    <message>
        <source>Log</source>
        <translation>Log</translation>
    </message>
    <message>
        <source>Automatically</source>
        <translation>Automatisch</translation>
    </message>
    <message>
        <source>Create images of tabs </source>
        <translation>Afbeeldingen maken van tabbladen</translation>
    </message>
    <message>
        <source>License information</source>
        <translation>Licentie informatie</translation>
    </message>
    <message>
        <source>ON</source>
        <translation>AAN</translation>
    </message>
    <message>
        <source>OFF</source>
        <translation>UIT</translation>
    </message>
    <message>
        <source>Global keyboard shortcuts</source>
        <translation>Globale sneltoetsen</translation>
    </message>
    <message>
        <source>Assigned shortcut keys.</source>
        <translation>Toegewezen sneltoetsen.</translation>
    </message>
    <message>
        <source>Keyboard shortcut not assigned or assigned more than once.</source>
        <translation>De sneltoets is niet of meer dan eens toegewezen.</translation>
    </message>
    <message>
        <source>If it shows assigned but does not work, it is being used by another program.</source>
        <translation>Als de sneltoets wordt aangeduid als toegewezen maar niet werkt, dan is de sneltoets reeds in gebruik door een ander programma.</translation>
    </message>
    <message>
        <source>Snapshot</source>
        <translation>Schermafbeelding</translation>
    </message>
    <message>
        <source>Imagepath</source>
        <translation>Afbeeldingslocatie</translation>
    </message>
    <message>
        <source>Hide this window</source>
        <translation>Venster verbergen</translation>
    </message>
    <message>
        <source>Seconds wait before recording</source>
        <translation>Aantal seconden voordat opname start</translation>
    </message>
    <message>
        <source>Window</source>
        <translation>Venster</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Volledig scherm</translation>
    </message>
</context>
<context>
    <name>formMainWindow_wl</name>
    <message>
        <source>Copyright and license from pictures</source>
        <translation>Copyright en licentie uit afbeeldingen</translation>
    </message>
    <message>
        <source>Create images of tabs </source>
        <translation>Afbeeldingen maken van tabbladen</translation>
    </message>
    <message>
        <source>License information</source>
        <translation>Licentie informatie</translation>
    </message>
    <message>
        <source>ON</source>
        <translation>AAN</translation>
    </message>
    <message>
        <source>OFF</source>
        <translation>UIT</translation>
    </message>
    <message>
        <source>Record Time:</source>
        <translation>Opnametijd:</translation>
    </message>
    <message>
        <source>Video size:</source>
        <translation>Videoformaat:</translation>
    </message>
    <message>
        <source>Free disk space:</source>
        <translation>Vrije schijfruimte:</translation>
    </message>
    <message>
        <source>Information</source>
        <translation>Informatie</translation>
    </message>
    <message>
        <source>Window</source>
        <translation>Venster</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Volledig scherm</translation>
    </message>
    <message>
        <source>Area</source>
        <translation>Gebied</translation>
    </message>
    <message>
        <source>Videocodec</source>
        <translation>Videocodec</translation>
    </message>
    <message>
        <source>Frames</source>
        <translation>Frames</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>Formaat</translation>
    </message>
    <message>
        <source>Available</source>
        <translation>Beschikbaar</translation>
    </message>
    <message>
        <source>Not available</source>
        <translation>Niet beschikbaar</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>Start</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Stop</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pauze</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Hervatten</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>Afspelen</translation>
    </message>
    <message>
        <source>Folder</source>
        <translation>Map</translation>
    </message>
    <message>
        <source>Do not record mouse cursor</source>
        <translation>Muis cursor niet opnemen</translation>
    </message>
</context>
<context>
    <name>license</name>
    <message>
        <source>Copyright and license from pictures</source>
        <translation>Copyright en licentie uit afbeeldingen</translation>
    </message>
</context>
<context>
    <name>playerGST</name>
    <message>
        <source>Play</source>
        <translation>Afspelen</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pauze</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Stop</translation>
    </message>
</context>
</TS>